timeseries.fast_algorithms — GDA Toolbox v1.0 Manual

# timeseries.fast_algorithms

This Cython module contains core algorithms for `timeseries.Signal` data. In particular, some feature extraction.

If a function requires its own explicit iterator in a loop, probably it should go here. Anything that is just a vectorized operation in NumPy or Pandas can go in plain python elsewhere.

See http://docs.cython.org/src/tutorial/np.html for ideas on writing efficient code in Cython.

This module is compiled by either of these commands
  - `python setup.py install` (as called by `pip` for standard installation and use)
  - `python setup.py build_ext --inplace` (as run by developers for code testing)

## Notes

Automatically-generated online documentation will never see the C-only functions that are defined with `cdef` in Cython, as shown in http://cython.readthedocs.io/en/latest/src/reference/extension_types.html Because of the limitations of Sphinx, you’ll have to simply view the sourcecode for further information. For this module, these C-only functions include

> - (none currently)

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Functions

`mkforestINT` | make inclusion tree and parentage linked lists by walking across open/closed parentheses.
`sample_height` | measure H_A: U to R on Omega.

### Table of Contents

- timeseries.fast_algorithms
  - Notes
  - Copyright

#### Previous topic

multidim.fast_algorithms

#### Next topic

timeseries.curve_geometry